==> moodle-1.5-mysql.tgz: moodle/lang/pt_br/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4.1 (2004083101)


$string['addresource'] = 'Adicionar material';
$string['chooseafile'] = 'Escolher ou carregar arquivo';
$string['chooseparameter'] = 'Escolher parmentro';
$string['configdefaulturl'] = 'Este valor  usado para completar o form da URL automaticamente quando o material  baseado em URL';
$string['configfilterexternalpages'] = 'Se esta opo estiver ativa, todos os materiais externos como paginas web e arquivos html carregados no servidor sero processados pelos filtros do site, como os autolinks do glossrio. Isto pode reduzir a velocidade de visualizao das pginas do curso - use esta opo apenas nos casos em que for realmente necessrio.';
$string['configframesize'] = 'Quando uma pgina web ou um arquivo  visualizado em um frame, este valor  o tamanho, em pixels, do frame que contm a navegao (top frame).';
$string['configparametersettings'] = 'Isto define o valr padro dos parmetros do painel do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['configpopup'] = 'A opo de visualizar os materiais em janela popup deve ser preconfigurada?';
$string['configpopupdirectories'] = 'As janelas popup devem mostrar o diretrio de links?';
$string['configpopupheight'] = 'Qual  a altura predefinida das janelas popup?';
$string['configpopuplocation'] = 'As janelas popup devem mostrar a barra de endereo?';
$string['configpopupmenubar'] = 'As janelas popup devem mostrar a barra do menu?';
$string['configpopupresizable'] = 'As janelas popup podem ser redimensionadas?';
$string['configpopupscrollbars'] = 'As janelas popup devem ter a barra de rolagem?';
$string['configpopupstatus'] = 'As janelas popup devem mostrar a brra de estado?';
$string['configpopuptoolbar'] = 'As janelas popup devem  mostrar a barra de instrumentos?';
$string['configpopupwidth'] = 'Qual  a largura predefinida das janelas popup?';
$string['configsecretphrase'] = 'Esta frase secreta  usada para produzir cdigos com valres cifrados que podem ser enviados aos materiais como parmetros. O cdigo cifrado  produzido por um valr md5 do endereo IP ligado a current_users e concatenado  frase secreta: code = md5(IP.secretphrase). isto permite ao destinatrio de verificar a conexo como medida adicional de segurana.';
$string['configwebsearch'] = 'Quando se adiciona uma URL como uma pgina web ou link, este endereo  apresentado como referimento para ajudar o usurio a buscar a URL que est procurando.';
$string['configwindowsettings'] = 'Isto define o valr padro do painel de configurao da janela do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['directlink'] = 'Direcionar link a este arquivo';
$string['directoryinfo'] = 'Todos os documentos no diretrio selecionado sero visualizados';
$string['display'] = 'Janela';
$string['editingaresource'] = 'Editar material';
$string['encryptedcode'] = 'Cdigo cifrado';
$string['example'] = 'Exemplo';
$string['exampleurl'] = 'http://www.exemplo.com/diretorio/arquivo.html';
$string['fetchclienterror'] = 'Um erro relacionado ao seu navegador impediu o acesso a este endereo (provavelmente o endereo no existe ou foi escrito em modo impreciso)';
$string['fetcherror'] = 'No foi possvel o acesso a esta pgina.';
$string['fetchservererror'] = 'Um erro de acesso ao servidor remoto foi identificado (provavelmente um erro daquele programa)';
$string['filename'] = 'Nome do arquivo';
$string['filtername'] = 'Link automtico aos materiais';
$string['frameifpossible'] = 'Colocar o material em un frame par que a navegao do site continue visvel';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['maindirectory'] = 'Diretrio principal';
$string['modulename'] = 'Material';
$string['modulenameplural'] = 'Materiais';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar links do diretrio';
$string['newfullscreen'] = 'Preencher toda a tela';
$string['newheight'] = 'Altura predefinida da janela (em pixels)';
$string['newlocation'] = 'Mostrar a brra de endereo';
$string['newmenubar'] = 'Mostrar a barra de menu';
$string['newresizable'] = 'Permitir redimensionamento da janela';
$string['newscrollbars'] = 'Permitir o escorrimento da janela';
$string['newstatus'] = 'Mostrar a barra de status';
$string['newtoolbar'] = 'Mostrar a barra de instrumentos';
$string['newwidth'] = 'Largura predefinida da janela (em pixels)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostre este material em uma janela popup';
$string['note'] = 'Nota';
$string['notefile'] = 'Para transferir mais arquivos ao curso (in modo que aparecerem nesta lista) use o <a href="\$a"\>Administrador de Arquivos</a>.';
$string['notypechosen'] = 'Voc tem que escolher um tipo. Use seu boto de retorno e tente novamente.';
$string['pagedisplay'] = 'Visualizar este material nesta janela';
$string['pagewindow'] = 'Mesma janela';
$string['parameter'] = 'Parmetro';
$string['parameters'] = 'Parmetros';
$string['popupresource'] = 'Este material deve ser mostrado em uma janela popup';
$string['popupresourcelink'] = 'Em caso contrrio, clicar aqui: $a';
$string['resourcetype'] = 'Tipo de material';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina Web';
$string['resourcetype3'] = 'Arquivo transferido ao site';
$string['resourcetype4'] = 'Texto Simples';
$string['resourcetype5'] = 'Link Web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto WIKI';
$string['resourcetype9'] = 'Diretrio';
$string['resourcetypedirectory'] = 'Visualizar diretrio';
$string['resourcetypefile'] = 'Fazer link a um arquivo ou site';
$string['resourcetypehtml'] = 'Criar uma pgina web';
$string['resourcetypelabel'] = 'Inserir rtulo';
$string['resourcetypetext'] = 'Criar uma pgina de texto simples';
$string['searchweb'] = 'Buscar pgina web';
$string['variablename'] = 'Nome da varivel';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/pt_br/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 + (2005060201)


$string['addresource'] = 'Adicionar material';
$string['chooseafile'] = 'Escolher ou enviar arquivo';
$string['chooseparameter'] = 'Escolher parmetro';
$string['configallowlocalfiles'] = 'Quando criar um novo material, permita links a arquivos do sistema local, como um CD ou um disco rgido. Isto pode ser til numa classe onde todos os estudantes tem acesso ao mesmo dispositivo da rede ou quando  necessrio acessar arquivos de um CD. O uso desta funcionalidade pode exigir a mudana da configurao de segurana de seu navegador.';
$string['configdefaulturl'] = 'Este valor  usado para completar o form da URL automaticamente quando o material  baseado em URL';
$string['configfilterexternalpages'] = 'Se esta opo estiver ativa, todos os materiais externos como paginas web e arquivos html carregados no servidor sero processados pelos filtros do site, como os autolinks do glossrio. Isto pode reduzir a velocidade de visualizao das pginas do curso - use esta opo apenas nos casos em que for realmente necessrio.';
$string['configframesize'] = 'Quando uma pgina web ou um arquivo  visualizado em um frame, este valor  o tamanho, em pixels, do frame que contm a navegao (top frame).';
$string['configparametersettings'] = 'Isto define o valr padro dos parmetros do painel do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['configpopup'] = 'A opo de visualizar os materiais em janela popup deve ser preconfigurada?';
$string['configpopupdirectories'] = 'As janelas popup devem mostrar o diretrio de links?';
$string['configpopupheight'] = 'Qual  a altura predefinida das janelas popup?';
$string['configpopuplocation'] = 'As janelas popup devem mostrar a barra de endereo?';
$string['configpopupmenubar'] = 'As janelas popup devem mostrar a barra de menu?';
$string['configpopupresizable'] = 'As janelas popup podem ser redimensionadas?';
$string['configpopupscrollbars'] = 'As janelas popup devem ter a barra de rolagem?';
$string['configpopupstatus'] = 'As janelas popup devem mostrar a barra de status?';
$string['configpopuptoolbar'] = 'As janelas popup devem  mostrar a barra de ferramentas?';
$string['configpopupwidth'] = 'Qual  a largura predefinida das janelas popup?';
$string['configsecretphrase'] = 'Esta frase secreta  usada para produzir cdigos com valres cifrados que podem ser enviados aos materiais como parmetros. O cdigo cifrado  produzido por um valr md5 do endereo IP ligado a current_users e concatenado  frase secreta: code = md5(IP.secretphrase). isto permite ao destinatrio de verificar a conexo como medida adicional de segurana.';
$string['configwebsearch'] = 'Quando se adiciona uma URL como uma pgina web ou link, este endereo  apresentado como referimento para ajudar o usurio a buscar a URL que est procurando.';
$string['configwindowsettings'] = 'Isto define o valr padro do painel de configurao da janela do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['directlink'] = 'Direcionar link a este arquivo';
$string['directoryinfo'] = 'Todos os documentos no diretrio selecionado sero visualizados';
$string['display'] = 'Janela';
$string['editingaresource'] = 'Editar material';
$string['encryptedcode'] = 'Cdigo cifrado';
$string['example'] = 'Exemplo';
$string['exampleurl'] = 'http://www.exemplo.com/diretorio/arquivo.html';
$string['fetchclienterror'] = 'Um erro relacionado ao seu navegador impediu o acesso a este endereo (provavelmente o endereo no existe ou foi escrito em modo impreciso)';
$string['fetcherror'] = 'No foi possvel o acesso a esta pgina.';
$string['fetchservererror'] = 'Um erro de acesso ao servidor remoto foi identificado (provavelmente um erro daquele programa)';
$string['filename'] = 'Nome do arquivo';
$string['filtername'] = 'Link automtico aos materiais';
$string['frameifpossible'] = 'Colocar o material em un frame par que a navegao do site continue visvel';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['localfile'] = 'Arquivo local';
$string['localfilechoose'] = 'Escolha um arquivo local (CD-ROM)';
$string['localfilehelp'] = 'Ajuda para visualizao dos arquivos locais';
$string['localfileinfo'] = '<p>Escolha um arquivo local em seu computador. O arquivo no ser enviado para o servidor mas o sistema vai procurar este mesmo arquivo no computador de qualquer pessoa que esteja acessando este material.</p><p>Isto  til quando voc tem arquivos multimediais grandes armazenados em CD-ROMs standard que so distribudos a todos os participantes. Cada participante pode escolher seu prprio caminho de acesso a estes arquivos, <a href=\"$a\" target=\"_blank\">editando seu perfil de usurio</a>.</p>';
$string['localfilepath'] = 'Para definir o percurso de acesso deste material, escolha qualquer arquivo do dispositivo do seu computador que contm o material (normalmente um CD-ROM) . Este arquivo no ser enviado, mas a informao sobre o dispositivo ser arquivada e usada para futuros acesso a recursos locais.';
$string['localfileselect'] = 'Escolha o caminho de acesso a este arquivo';
$string['maindirectory'] = 'Diretrio principal';
$string['modulename'] = 'Material';
$string['modulenameplural'] = 'Materiais';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar diretrio de links';
$string['newfullscreen'] = 'Preencher toda a tela';
$string['newheight'] = 'Altura predefinida da janela (em pixels)';
$string['newlocation'] = 'Mostrar a barra de localizao';
$string['newmenubar'] = 'Mostrar a barra de menu';
$string['newresizable'] = 'Permitir redimensionamento da janela';
$string['newscrollbars'] = 'Permitir a rolagem da janela';
$string['newstatus'] = 'Mostrar a barra de estado';
$string['newtoolbar'] = 'Mostrar a barra de ferramentas';
$string['newwidth'] = 'Largura predefinida da janela (em pixels)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostre este material em uma janela popup';
$string['notallowedlocalfileaccess'] = 'O acesso a arquivos locais est disabilitado, portanto este material no pode ser acessado';
$string['note'] = 'Nota';
$string['notefile'] = 'Para transferir mais arquivos ao curso (in modo que aparecerem nesta lista) use o <a href=\"$a\">Administrador de Arquivos</a>.';
$string['notypechosen'] = 'Voc tem que escolher um tipo. Use seu boto de retorno e tente novamente.';
$string['pagedisplay'] = 'Visualizar este material nesta janela';
$string['pagewindow'] = 'Mesma janela';
$string['pan'] = 'Pan';
$string['parameter'] = 'Parmetro';
$string['parameters'] = 'Parmetros';
$string['popupresource'] = 'Este material deve ser mostrado em uma janela popup';
$string['popupresourcelink'] = 'Em caso contrrio, clicar aqui: $a';
$string['resourcetype'] = 'Tipo de material';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina Web';
$string['resourcetype3'] = 'Arquivo transferido ao site';
$string['resourcetype4'] = 'Texto Simples';
$string['resourcetype5'] = 'Link Web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto WIKI';
$string['resourcetype9'] = 'Diretrio';
$string['resourcetypedirectory'] = 'Visualizar um diretrio';
$string['resourcetypefile'] = 'Link a um arquivo ou site';
$string['resourcetypehtml'] = 'Criar uma pgina web';
$string['resourcetypelabel'] = 'Inserir rtulo';
$string['resourcetypetext'] = 'Criar uma pgina de texto simples';
$string['searchweb'] = 'Buscar pgina web';
$string['serverurl'] = 'URL do servidor  ($a->wwwroot)';
$string['variablename'] = 'Nome da varivel';
$string['vol'] = 'Vol';

?>
